pub enum EncodeBytes {
One = 1,
Two = 2,
Four = 4,
Eight = 8,
}Expand description
The number of bytes that a QUIC variable-length integer can be encoded in.
VarInt doesn’t need to be encoded on the minimum number of bytes necessary,
with the sole exception of the Frame Type field.
Variants