pub struct VarInt(/* private fields */);Expand description
An integer less than 2^62
Values of this type are suitable for encoding as QUIC variable-length integer. It would be neat if we could express to Rust that the top two bits are available for use as enum discriminants
See variable-length integers of QUIC for more details.
Implementations
Sourceimpl VarInt
impl VarInt
Sourcepub const fn from_u64(value: u64) -> Result<Self, Overflow>
pub const fn from_u64(value: u64) -> Result<Self, Overflow>
Construct a VarInt from a u64.
Succeeds if x < 2^62.
Sourcepub unsafe fn from_u64_unchecked(x: u64) -> Self
pub unsafe fn from_u64_unchecked(x: u64) -> Self
Sourcepub fn from_u128(value: u128) -> Result<Self, Overflow>
pub fn from_u128(value: u128) -> Result<Self, Overflow>
Construct a VarInt from a u128.
Succeeds if x < 2^62.
Sourcepub const fn into_inner(self) -> u64
pub const fn into_inner(self) -> u64
Extract the integer value
Sourcepub fn encoding_size(self) -> usize
pub fn encoding_size(self) -> usize
Compute the number of bytes needed to encode this value